#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua
version:              2.3.0
visibility:           public
id:                   hslua-2.3.0-7w039xwuzpcClmUy2szLK7
key:                  hslua-2.3.0-7w039xwuzpcClmUy2szLK7
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    HsLua provides wrappers and helpers
    to bridge Haskell and <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

    Example programs are can be found in the @hslua-examples@
    subdir of the project
    <https://github.com/hslua/hslua repository>.

category:             Foreign
abi:                  f11ebe023f1fd761e74ce784827f2515
exposed:              True
exposed-modules:
    HsLua,
    HsLua.Aeson from hslua-aeson-2.3.1.1-AapgaYCp5ENKTgGBxntW25:HsLua.Aeson,
    HsLua.Class.Exposable from hslua-classes-2.3.1-G6xT8Q1bowaA8pNz4acAIJ:HsLua.Class.Exposable,
    HsLua.Class.Invokable from hslua-classes-2.3.1-G6xT8Q1bowaA8pNz4acAIJ:HsLua.Class.Invokable,
    HsLua.Class.Peekable from hslua-classes-2.3.1-G6xT8Q1bowaA8pNz4acAIJ:HsLua.Class.Peekable,
    HsLua.Class.Pushable from hslua-classes-2.3.1-G6xT8Q1bowaA8pNz4acAIJ:HsLua.Class.Pushable,
    HsLua.Class.Util from hslua-classes-2.3.1-G6xT8Q1bowaA8pNz4acAIJ:HsLua.Class.Util,
    HsLua.Core from hslua-core-2.3.2-6FUr5NLEUJDEzv2Dv0EWm8:HsLua.Core,
    HsLua.Core.Error from hslua-core-2.3.2-6FUr5NLEUJDEzv2Dv0EWm8:HsLua.Core.Error,
    HsLua.Core.Types from hslua-core-2.3.2-6FUr5NLEUJDEzv2Dv0EWm8:HsLua.Core.Types,
    HsLua.Core.Utf8 from hslua-core-2.3.2-6FUr5NLEUJDEzv2Dv0EWm8:HsLua.Core.Utf8,
    HsLua.Marshalling from hslua-marshalling-2.3.1-BZX08IxoFzv4URbF6kPcxI:HsLua.Marshalling,
    HsLua.ObjectOrientation from hslua-objectorientation-2.3.1-8E0ZT5zZm8BG6SfUMXawNN:HsLua.ObjectOrientation,
    HsLua.Packaging from hslua-packaging-2.3.1-HZs5aFvSXdUEASyPKoXq99:HsLua.Packaging,
    HsLua.Packaging.Function from hslua-packaging-2.3.1-HZs5aFvSXdUEASyPKoXq99:HsLua.Packaging.Function,
    HsLua.Packaging.Module from hslua-packaging-2.3.1-HZs5aFvSXdUEASyPKoXq99:HsLua.Packaging.Module,
    HsLua.Packaging.Rendering from hslua-packaging-2.3.1-HZs5aFvSXdUEASyPKoXq99:HsLua.Packaging.Rendering,
    HsLua.Typing from hslua-typing-0.1.1-ELvGKl9pi0f8nATVBaVQz0:HsLua.Typing,
    HsLua.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua
hs-libraries:         HShslua-2.3.0-7w039xwuzpcClmUy2szLK7
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 hslua-aeson-2.3.1.1-AapgaYCp5ENKTgGBxntW25
    hslua-classes-2.3.1-G6xT8Q1bowaA8pNz4acAIJ
    hslua-core-2.3.2-6FUr5NLEUJDEzv2Dv0EWm8
    hslua-marshalling-2.3.1-BZX08IxoFzv4URbF6kPcxI
    hslua-objectorientation-2.3.1-8E0ZT5zZm8BG6SfUMXawNN
    hslua-packaging-2.3.1-HZs5aFvSXdUEASyPKoXq99
    hslua-typing-0.1.1-ELvGKl9pi0f8nATVBaVQz0 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html:         /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

